;;; SPDX-License-Identifier: GPL-3.0-or-later
;; Erlang package.

(define-module (glarus packages erlang)
  #:use-module (guix download)
  #:use-module (guix gexp)
  #:use-module (guix packages)
  #:use-module (guix utils)
  #:use-module (gnu packages)
  #:use-module ((gnu packages erlang) #:prefix gnu:)
  #:use-module (gnu packages perl))

(define-public erlang
  (let ((uri-prefix "https://github.com/erlang/otp/releases/download/OTP-"))
    (package/inherit gnu:erlang
      (name "erlang")
      (version "26.2.5")
      (source (origin
                (method url-fetch)
                (uri (string-append uri-prefix version "/otp_src_" version ".tar.gz"))
                (sha256
                 (base32
                  "1xn9hj2b5gjqhz0fkvkgvl25lmsmz4xx1nwndjg2paxsv555q5fy"))
                (patches (search-patches "erlang-man-path.patch"))))
      (arguments
       (substitute-keyword-arguments (package-arguments gnu:erlang)
         ((#:configure-flags flags #~'())
          #~(cons* "--enable-dirty-schedulers"
                   "--enable-kernel-poll"
                   "--enable-esock"
                   "--without-javac"
                   #$flags))
         ((#:phases phases)
          #~(modify-phases #$phases
              (add-after 'install-doc 'install-chunks
                (lambda* (#:key inputs outputs #:allow-other-keys)
                    (invoke "make" "install-docs" "DOC_TARGETS=chunks")))))))
      (native-inputs
       `(("perl" ,perl)
         ("erlang-manpages"
          ,(origin
             (method url-fetch)
             (uri (string-append uri-prefix version "/otp_doc_man_" version ".tar.gz"))
             (sha256
              (base32
               "08ngil8578asjzmqa657l4zdy0cr0h9spkg88wp9kxl95bfyli8p")))))))))
